@@ -1,14 +1,14 @@
 package App::riap;
 
-our $DATE = '2015-03-13'; # DATE
-our $VERSION = '0.31'; # VERSION
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.32'; # VERSION
 
 use 5.010001;
 use strict;
 use utf8;
 use warnings;
 #use experimental 'smartmatch';
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use parent qw(Term::Shell);
 
@@ -622,7 +622,7 @@ sub catch_comp {
     my $meta = $res->[2];
 
     my ($words, $cword) = @{ Complete::Bash::parse_cmdline(
-        $line, $start+length($word), '=') };
+        $line, $start+length($word)) };
     shift @$words; $cword--; # strip program name
     $opts = {};
     $res = Perinci::Sub::Complete::complete_cli_arg(
@@ -733,7 +733,7 @@ App::riap - Riap command-line client shell
 
 =head1 VERSION
 
-version 0.31
+version 0.32
 
 =head1 SYNOPSIS
 
