@@ -1,12 +1,12 @@
 package App::riap::Commands;
 
-our $DATE = '2015-03-13'; # DATE
-our $VERSION = '0.31'; # VERSION
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.32'; # VERSION
 
 use 5.010;
 use strict;
 use warnings;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use Path::Naive qw(is_abs_path normalize_path concat_path_n);
 #use Perinci::Sub::Util qw(err);
@@ -552,7 +552,7 @@ App::riap::Commands - riap shell commands
 
 =head1 VERSION
 
-version 0.31
+version 0.32
 
 =for Pod::Coverage .+
 
